<?php

namespace SGalinski\SgNews\Domain\Repository;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SGalinski\SgNews\Domain\Model\Category;
use TYPO3\CMS\Core\Database\ConnectionPool;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Persistence\Generic\Mapper\DataMapper;

/**
 * Category Repository
 */
class CategoryRepository extends AbstractRepository {
	/**
	 * Find the original language category record
	 *
	 * @param int $uid
	 * @return Category|null
	 */
	public function findOriginalLanguageById(int $uid): ?Category {
		$dataMapper = $this->objectManager->get(DataMapper::class);
		$queryBuilder = GeneralUtility::makeInstance(ConnectionPool::class)->getQueryBuilderForTable('pages');
		$row = $queryBuilder->select('default.*')
			->from('pages', 'translation')
			->leftJoin('translation', 'pages', 'default', 'translation.l10n_parent=default.uid')
			->where(
				$queryBuilder->expr()->eq('translation.uid', $queryBuilder->createNamedParameter($uid, \PDO::PARAM_INT))
			)
			->setMaxResults(1)
			->execute()->fetch();
		if ($row) {
			return current($dataMapper->map($this->objectType, [$row]));
		} else {
			return NULL;
		}
	}
}
